@@ -65,7 +65,7 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
 
     # Add new model
     def post_data_sampling_models_add(self, request_info, **kwargs):
-        """
+        r"""
         | trackme mode=post url=\"/services/trackme/v2/splk_data_sampling/write/data_sampling_models_add\" body=\"{'tenant_id':'mytenant', 'model_name':'Netscreen', 'model_type':'inclusive', 'model_regex':':\sNetScreen\sdevice_id=', 'sourcetype_scope': 'netscreen:firewall'}\"
         """
 
@@ -118,7 +118,7 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
             response = {
                 "describe": "This endpoint creates a new data sampling custom model, it requires a POST call with the following data:",
                 "resource_desc": "Add new Data Sampling custom model",
-                "resource_spl_example": "| trackme mode=post url=\"/services/trackme/v2/splk_data_sampling/write/data_sampling_models_add\" body=\"{'tenant_id':'mytenant', 'model_name':'Netscreen', 'model_type':'inclusive', 'model_regex':':\\\sNetScreen\\\sdevice_id=', 'sourcetype_scope': 'netscreen:firewall'}\"",
+                "resource_spl_example": r"| trackme mode=post url=\"/services/trackme/v2/splk_data_sampling/write/data_sampling_models_add\" body=\"{'tenant_id':'mytenant', 'model_name':'Netscreen', 'model_type':'inclusive', 'model_regex':':\\\sNetScreen\\\sdevice_id=', 'sourcetype_scope': 'netscreen:firewall'}\"",
                 "options": [
                     {
                         "model_name": "name of the custom model",
@@ -283,8 +283,9 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
             if not describe:
                 tenant_id = resp_dict["tenant_id"]
                 models_list = resp_dict["models_list"]
-                # Handle as a CSV list of keys
-                models_list = models_list.split(",")
+                # if not a list already, convert to a list from comma separated string
+                if not isinstance(models_list, list):
+                    models_list = models_list.split(",")
 
         else:
             # body is required in this endpoint, if not submitted describe the usage
@@ -346,7 +347,7 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
 
         # loop
         for item in models_list:
-            # Define the KV query
+            # Try to find the record by _key first (for backward compatibility)
             query_string = {
                 "_key": item,
             }
@@ -356,9 +357,21 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
             try:
                 kvrecord = collection.data.query(query=json.dumps(query_string))[0]
                 key = kvrecord.get("_key")
-
             except Exception as e:
                 key = None
+                kvrecord = None
+
+            # If not found by _key, try model_id (for new UI calls)
+            if not key:
+                query_string = {
+                    "model_id": item,
+                }
+                try:
+                    kvrecord = collection.data.query(query=json.dumps(query_string))[0]
+                    key = kvrecord.get("_key")
+                except Exception as e:
+                    key = None
+                    kvrecord = None
 
             # Render result
             if key:
@@ -507,7 +520,15 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
             if not describe:
                 tenant_id = resp_dict["tenant_id"]
                 records_list = resp_dict["records_list"]
-                records_list = json.loads(records_list)
+                # handle records_list, if not an object attempt json loads
+                if not isinstance(records_list, list) and not isinstance(records_list, dict):
+                    try:
+                        records_list = json.loads(records_list)
+                    except Exception as e:
+                        return {
+                            "payload": f"records_list is not a valid JSON: {str(e)}",
+                            "status": 500,
+                        }
 
         else:
             # body is required in this endpoint, if not submitted describe the usage
