@@ -97,7 +97,7 @@ class TrackMeTrackerExecutor(GeneratingCommand):
         require=True,
         default=None,
         validate=validators.Match(
-            "mode", r"^(?:splk-dsm|splk-dhm|splk-mhm|splk-flx|splk-wlk|splk-cim|splk-fqm)$"
+            "mode", r"^(?:splk-dsm|splk-dhm|splk-mhm|splk-flx|splk-wlk|splk-fqm)$"
         ),
     )
 
@@ -216,7 +216,6 @@ class TrackMeTrackerExecutor(GeneratingCommand):
         if license_is_valid != 1 and self.component in (
             "splk-flx",
             "splk-wlk",
-            "splk-cim",
             "splk-fqm",
         ):
 
